@@ -33,57 +33,10 @@ circle      3-tuple of center (point), normal (vector) and radius (float).
 
 .. note::
 
-    Many functions have a `_xy` variant. These variants ignore the Z-component of
-    the input parameters and return a result in the XY plane (with `z = 0`).
+    Many functions have an ``_xy`` variant. These variants ignore the Z-component of
+    the input parameters and return a result in the XY plane (with ``z = 0``).
 
 
-Linalg
-------
-
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    add_vectors
-    add_vectors_xy
-    sum_vectors
-    cross_vectors
-    cross_vectors_xy
-    divide_vectors
-    divide_vectors_xy
-    dot_vectors
-    dot_vectors_xy
-    length_vector
-    length_vector_xy
-    length_vector_sqrd
-    length_vector_sqrd_xy
-    multiply_matrices
-    multiply_matrix_vector
-    multiply_vectors
-    multiply_vectors_xy
-    norm_vector
-    norm_vectors
-    normalize_vector
-    normalize_vector_xy
-    normalize_vectors
-    normalize_vectors_xy
-    orthonormalize_vectors
-    power_vector
-    power_vectors
-    scale_vector
-    scale_vector_xy
-    scale_vectors
-    scale_vectors_xy
-    square_vector
-    square_vectors
-    subtract_vectors
-    subtract_vectors_xy
-    transpose_matrix
-    vector_component
-    vector_component_xy
-
--------
-
 Angles
 ------
 
@@ -219,6 +172,51 @@ Isolines
 
     scalarfield_contours_numpy
 
+Linalg
+------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    add_vectors
+    add_vectors_xy
+    sum_vectors
+    cross_vectors
+    cross_vectors_xy
+    divide_vectors
+    divide_vectors_xy
+    dot_vectors
+    dot_vectors_xy
+    length_vector
+    length_vector_xy
+    length_vector_sqrd
+    length_vector_sqrd_xy
+    multiply_matrices
+    multiply_matrix_vector
+    multiply_vectors
+    multiply_vectors_xy
+    norm_vector
+    norm_vectors
+    normalize_vector
+    normalize_vector_xy
+    normalize_vectors
+    normalize_vectors_xy
+    orthonormalize_vectors
+    power_vector
+    power_vectors
+    scale_vector
+    scale_vector_xy
+    scale_vectors
+    scale_vectors_xy
+    square_vector
+    square_vectors
+    subtract_vectors
+    subtract_vectors_xy
+    transpose_matrix
+    vector_component
+    vector_component_xy
+
 Normals
 -------
 
