@@ -7,13 +7,7 @@ from OpenGL.GLU import *
 from OpenGL.GL import *
 
 
-__author__     = ['Tom Van Mele <vanmelet@ethz.ch>', ]
-__copyright__  = 'Copyright 2014, Block Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
-__all__ = ['Arrow', ]
+__all__ = ['Arrow']
 
 
 class Arrow(object):
