@@ -17,13 +17,7 @@ else:
 from compas.viewers.core.qcolorbutton import QColorButton
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2016 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
-__all__ = ['ColorButton', ]
+__all__ = ['ColorButton']
 
 
 class ColorButton(object):
